.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:


Acknowledgments
***************

NICEMAN development is being performed as part of an NIH_ funded
(1P41EB019936-01A1_) "Center for Reproducible Neuroimaging Computation
(CRNC)". It's initial development aims to provide a suite of tools for
management of computational environments, which is the TR&D 3 sub-project of
the CRNC, and is lead by Dr. Halchenko_.

.. _1P41EB019936-01A1: https://projectreporter.nih.gov/project_info_details.cfm?aid=8999833&map=y
.. _Kennedy: http://haxbylab.dartmouth.edu/ppl/yarik.html
.. _Halchenko: http://haxbylab.dartmouth.edu/ppl/yarik.html
.. _NIH : http://nih.gov
